/*******************************************************************
Jan Cermak | johniez | aspt.johniez.com
Creative Commons 2.5 Attribution-NonCommercial-NoDerivs 2.5 license
http://creativecommons.org/licenses/by-nc-nd/2.5/legalcode
*******************************************************************/

#include "configtab.h"

/**
 * \brief Config Tab constructor.
 */
ConfigTab::ConfigTab(QWidget *parent): QWidget(parent) {
	file = 0;
	http = new QHttp("https://www.soccerproject.com/sptd.php", QHttp::ConnectionModeHttps, 443);
	QSettings settings("config/global.ini", QSettings::IniFormat);
	langToSave = settings.value("lang", 0).toInt();
	useProxy = settings.value("Network/proxyUsed", 0).toInt();
	num = settings.value("nextXmlId", "0").toString();
	//old data count
	int val = num.toInt(); val--;
	QString old;
	old.setNum(val);
	parse("data/data_"+old+".xml");
	
	connect(http, SIGNAL(requestFinished(int, bool)), this, SLOT(httpRequestFinished(int, bool)));
	connect(http, SIGNAL(responseHeaderReceived(const QHttpResponseHeader &)), this, SLOT(readResponseHeader(const QHttpResponseHeader &)));
	
	msgbox = new QLabel("");
	connect(this, SIGNAL(errMsgBox(const QString &)), this, SLOT(showMsgBox(const QString &)));
	
	nick = new QLineEdit("");
	pass = new QLineEdit("");
	nick->setText(settings.value("username", "").toString());
	warnLabel = new QLabel(tr("<span style=\"color:red;\">Warning:</span><br>You can download data file only once between simulations.<br>Data files could be used for building statistics, do not delete them.<br>If you want to download your data, type your soccerproject.com login details.<br>Bugs or feature requests on: http://flyspray.johniez.com/proj2"));
	nickLabel = new QLabel(tr("soccerproject.com <span style=\"color:red;\">nickname:</span>"));
	passLabel = new QLabel(tr("soccerproject.com <span style=\"color:red;\">password:</span>"));
	pass->setEchoMode(QLineEdit::Password);
	butDown = new QPushButton(tr("Download"));
	connect(butDown, SIGNAL(clicked()), this, SLOT(downloadLatest()));
	butProxy = new QPushButton(tr("Proxy server settings"));
	connect(butProxy, SIGNAL(clicked()), this, SLOT(openProxy()));
	proxyWin = 0;

	group1 = new QGroupBox(tr("Users data download"));
	group1Layout = new QVBoxLayout;
	group1Layout->addWidget(warnLabel);
	row1 = new QHBoxLayout();
	row1->addWidget(nickLabel);
	row1->addWidget(nick);
	group1Layout->addLayout(row1);
	row2 = new QHBoxLayout();
	row2->addWidget(passLabel);
	row2->addWidget(pass);
	group1Layout->addLayout(row2);
	group1Layout->addWidget(butDown);
	group1Layout->addWidget(butProxy);
	group1Layout->addWidget(msgbox);
	group1->setLayout(group1Layout);
	group2 = new QGroupBox(tr("Language selection"));
	group2Layout = new QVBoxLayout;
	lang = new QComboBox();
	lang->addItem(tr("English"), "en");
	lang->addItem(tr("Czech"), "cs");
	lang->addItem(tr("Romanian"), "ro");
	lang->addItem(tr("Polish"), "pl");
	lang->addItem(tr("Lithuanian"), "lt");
	lang->setCurrentIndex(lang->findData(settings.value("lang", "en").toString()));
	setLang = new QPushButton(tr("save change"));
	langWarn = new QLabel(tr("Language selection take effect after application restart."));
	group2Layout->addWidget(langWarn);
	group2Layout->addWidget(lang);
	group2Layout->addWidget(setLang);
	connect(lang, SIGNAL(activated(int)), this, SLOT(changeLang(int)));
	connect(setLang, SIGNAL(clicked()), this, SLOT(saveSettings()));
	group2->setLayout(group2Layout);
	mainLayout = new QVBoxLayout;
	mainLayout->addWidget(group1);
	mainLayout->addWidget(group2);
	setLayout(mainLayout);
}

/**
 * \brief Config Tab destructor.
 */
ConfigTab::~ConfigTab() {
	if(file) delete file;
	delete http;
	delete nick;
	delete pass;
	delete butDown;
	delete butProxy;
	delete msgbox;
	if(proxyWin) delete proxyWin;
	delete warnLabel;
	delete nickLabel;
	delete passLabel;
	delete lang;
	delete setLang;
	delete langWarn;
	delete row1;
	delete row2;
	delete group1Layout;
	delete group1;
	delete group2Layout;
	delete group2;
	delete mainLayout;
}

/**
 * \brief Slot assigned to language change action.
 * \param langId language ID.
 */
void ConfigTab::changeLang(int langId) {
	langToSave = langId;
}

/**
 * \brief Slot assigned to proxy settings opening action.
 */
void ConfigTab::openProxy() {
	proxyWin = new ProxySet();
}

/**
 * \brief Slot assigned to save button click.
 */
void ConfigTab::saveSettings() {
	const char* langs[] = {"en", "cs", "ro", "pl", "lt"};
	const unsigned langSize = sizeof(langs) / sizeof(char *);
	QSettings settings("config/global.ini", QSettings::IniFormat);
	settings.setValue("lang", langs[langToSave % langSize]);
	settings.sync();
}

/**
 * \brief Slot assigned to download button click.
 */
void ConfigTab::downloadLatest() {
	QSettings settings("config/global.ini", QSettings::IniFormat);
	useProxy = settings.value("Network/proxyUsed", 0).toInt();
	butDown->setEnabled(false);
	msgbox->setText("downloading...");
	file = new QFile("data/data_"+num+".xml");
	file->open(QIODevice::WriteOnly);
	QUrl url("https://www.soccerproject.com/sptd.php");
	int p_port = settings.value("Network/proxyPort", 443).toInt();
	if(useProxy) http->setProxy(settings.value("Network/proxyAddr", "").toString(), p_port, settings.value("Network/proxyName", "").toString(), settings.value("Network/proxyPass", "").toString());
	http->setHost(url.host(), QHttp::ConnectionModeHttps, 443);
	//QTextStream out(stdout); out << "log";
	httpId = http->get(url.path() + "?login=" + QUrl::toPercentEncoding(nick->text()) + "&pw=" + QUrl::toPercentEncoding(pass->text()) + "&sptdid=8&sptdpw=Cerm12", file);
	settings.setValue("username", nick->text());
	settings.sync();
}

/**
 * \brief Slot assigned to download finished action.
 */
void ConfigTab::httpRequestFinished(int requestId, bool error) {
	if (requestId != httpId) return;

	file->close();

	if (error) {
		file->remove();
		emit errMsgBox(tr("Download failed: %1.").arg(http->errorString()));
	} else {
		QFile control("data/data_"+num+".xml");
		control.open(QIODevice::ReadOnly);
		char c;
		control.getChar(&c);
		if(c == '<') {
			control.close();
			QSettings settings("config/global.ini", QSettings::IniFormat);
			QString parseNum = num;
			int val = num.toInt();
			num.setNum(++val);
			settings.setValue("nextXmlId", num);
			settings.sync();
			emit errMsgBox(QString("<span style=\"color:green;\">") + tr("Download OK") + "</span>");
			parse("data/data_"+parseNum+".xml");
			emit dataLoaded();
		} else {
			char err[512];
			control.ungetChar(c);
			control.readLine(err, sizeof(err));
			control.close();
			emit errMsgBox(QString("<span style=\"color:red;\">") + tr("Error: ") + err + "</span>");
			butDown->setEnabled(true);
		}
	}
	delete file;
	file = 0;
}

/**
 * \brief Slot assigned to QHttp response action.
 * \param responseHeader QHttp response.
 */
void ConfigTab::readResponseHeader(const QHttpResponseHeader &responseHeader) {
	if (responseHeader.statusCode() != 200) {
		QMessageBox::information(this, tr("HTTP"), tr("Download failed: %1.").arg(responseHeader.reasonPhrase()));
		http->abort();
		return;
	}
}

/**
 * \brief Slot assigned to errMsgBox signal.
 * \param text text to show.
 */
void ConfigTab::showMsgBox(const QString &text) {
	msgbox->clear();
	msgbox->setText(text);
}
