/*******************************************************************
Jan Cermak | johniez | aspt.johniez.com
Creative Commons 2.5 Attribution-NonCommercial-NoDerivs 2.5 license
http://creativecommons.org/licenses/by-nc-nd/2.5/legalcode
*******************************************************************/

#include "loadtab.h"

/**
 * \brief Load Tab constructor.
 */
LoadTab::LoadTab(QWidget * parent) : QWidget(parent) {
	init();
}

/**
 * \brief Load Tab destructor.
 */
LoadTab::~LoadTab() {
	delete label;
	delete older;
	delete mainLayout;
}

/**
 * Init UI for this tab.
 */
void LoadTab::init() {
	QSettings settings("config/global.ini", QSettings::IniFormat);
	QString num = settings.value("nextXmlId", "0").toString();
	
	QDate initDay(2004, 7, 5);
	
	older = new QComboBox();
	
	int j = 0;
	for(int i=num.toInt()-1; i>=0; i--) {
		quickparse("data/data_"+QString().setNum(i)+".xml");		// should be stored somewhere else
		if(globSlot) {
			dataParsed[j][0] = globSlot;
			dataParsed[j][1] = curSlot;
			dataParsed[j][2] = curSeason;
			dataParsed[j][3] = i;
		}
		QDate cDate = initDay.addDays((dataParsed[j][0]-1)/5);
		QString time;
		switch((dataParsed[j][0]-1)%5) {
			case 0: time = " 4:00-10:00"; break;
			case 1: time = " 10:00-14:00"; break;
			case 2: time = " 14:00-18:00"; break;
			case 3: time = " 18:00-22:00"; break;
			case 4: time = " 22:00-4:00"; break;
		}
		older->addItem("S:" + QString().setNum(dataParsed[j][2]) + " - " + cDate.toString("d.M.yyyy") + time, "");
		j++;
		if(j>=20) break;
	}
	
	mainLayout = new QVBoxLayout;
	QString text;
	
	label = new QLabel(text);
	mainLayout->addWidget(older);
	mainLayout->addWidget(label);
	setLayout(mainLayout);
	connect(older, SIGNAL(currentIndexChanged(int)), this, SLOT(indexChanged(int)));
}

/**
 * \brief Slot assigned to data change action.
 */
void LoadTab::dataChanged() {
	rebuildUI();
}

/**
 * \brief Slot assigned to combobox index change.
 * \param i selected index.
 */
void LoadTab::indexChanged(int i) {
	int fileNum = dataParsed[i][3];
	parse("data/data_" + QString().setNum(fileNum) + ".xml");
	emit loaded();
	label->clear();
	label->setText(tr("Loaded file: ") + "data_" + QString().setNum(fileNum) + ".xml");
}

/**
 * \brief Delete UI and draw it again.
 */
void LoadTab::rebuildUI() {
	delete older;
	delete label;
	delete mainLayout;
	init();
}
