/*******************************************************************
Jan Cermak | johniez | aspt.johniez.com
Creative Commons 2.5 Attribution-NonCommercial-NoDerivs 2.5 license
http://creativecommons.org/licenses/by-nc-nd/2.5/legalcode
*******************************************************************/

#include "main.h"

void parse(const QString &data);

int playerCnt;		///< number of players parsed
Player pls[45];		///< parsed players array
int staffCnt;		///< number of staff parsed
StaffMemberStruct staff[7];		///< parsed staff array
StadiumStruct stadium;		///< parsed stadium
ClubStruct club;		///< parsed club
int dataParsed[20][4];
int globSlot, curSlot, curSeason;

/**
 * \brief Function parsing input XML.
 *
 * Parse players, staff, stadium etc. info from soccerproject XML.
 * \param[in] data path to input xml.
 */
void parse(const QString &data) {
	QDomDocument doc("spdt");
	QFile file( data );
	file.open( QIODevice::ReadOnly );
	doc.setContent( &file );
	file.close();
	
	playerCnt = 0;
	staffCnt = 0;
	
	QDomElement root = doc.documentElement();
	if( root.tagName() == "SoccerProject" ) {
		QDomNode n = root.firstChild();
		
		while( !n.isNull() ) {
			QDomElement e = n.toElement();
			if( !e.isNull() ) {
				if( e.tagName() == "GlobalInfo" ) {
					QDomNode ID = e.firstChild();
					while( !ID.isNull() ) {
						QDomElement IDD = ID.toElement();
						if(IDD.tagName() == "cur_globalslot" ) {
							QDomElement pl = IDD.toElement();
							globSlot = pl.text().toInt();
						}
						if(IDD.tagName() == "cur_slot" ) {
							QDomElement pl = IDD.toElement();
							curSlot = pl.text().toInt();
						}
						if(IDD.tagName() == "cur_season" ) {
							QDomElement pl = IDD.toElement();
							curSeason = pl.text().toInt();
						}
						ID = ID.nextSibling();
					}
				}
				if( e.tagName() == "Club" ) {
					QDomNode ID = e.firstChild();
					while( !ID.isNull() ) {
						QDomElement IDD = ID.toElement();
						if(IDD.tagName() == "name" ) {
							QDomElement pl = IDD.toElement();
							club.name = pl.text();
						}
						if(IDD.tagName() == "budg" ) {
							QDomElement pl = IDD.toElement();
							club.budget = pl.text();
						}
						if(IDD.tagName() == "rat" ) {
							QDomElement pl = IDD.toElement();
							club.rat = pl.text();
						}
						if(IDD.tagName() == "incup" ) {
							QDomElement pl = IDD.toElement();
							club.incup = pl.text().toInt();
						}
						if(IDD.tagName() == "fndd" ) {
							QDomElement pl = IDD.toElement();
							club.fndd = pl.text();
						}
						if(IDD.tagName() == "spirit" ) {
							QDomElement pl = IDD.toElement();
							club.spirit = pl.text();
						}
						if(IDD.tagName() == "curpos" ) {
							QDomElement pl = IDD.toElement();
							club.curpos = pl.text();
						}
						if(IDD.tagName() == "curdiv" ) {
							QDomElement pl = IDD.toElement();
							club.curdiv = pl.text();
						}
						if(IDD.tagName() == "totgmade" ) {
							QDomElement pl = IDD.toElement();
							club.totgmade = pl.text();
						}
						if(IDD.tagName() == "totgrecv" ) {
							QDomElement pl = IDD.toElement();
							club.totgrecv = pl.text();
						}
						if(IDD.tagName() == "curgmade" ) {
							QDomElement pl = IDD.toElement();
							club.curgmade = pl.text();
						}
						if(IDD.tagName() == "curgrecv" ) {
							QDomElement pl = IDD.toElement();
							club.curgrecv = pl.text();
						}
						if(IDD.tagName() == "curlgmade" ) {
							QDomElement pl = IDD.toElement();
							club.curlgmade = pl.text();
						}
						if(IDD.tagName() == "curlgrecv" ) {
							QDomElement pl = IDD.toElement();
							club.curlgrecv = pl.text();
						}
						if(IDD.tagName() == "tothgames" ) {
							QDomElement pl = IDD.toElement();
							club.tothgames = pl.text();
						}
						if(IDD.tagName() == "totwins" ) {
							QDomElement pl = IDD.toElement();
							club.totwins = pl.text();
						}
						if(IDD.tagName() == "totdraws" ) {
							QDomElement pl = IDD.toElement();
							club.totdraws = pl.text();
						}
						if(IDD.tagName() == "totlosts" ) {
							QDomElement pl = IDD.toElement();
							club.totlosts = pl.text();
						}
						if(IDD.tagName() == "curhgames" ) {
							QDomElement pl = IDD.toElement();
							club.curhgames = pl.text();
						}
						if(IDD.tagName() == "curwins" ) {
							QDomElement pl = IDD.toElement();
							club.curwins = pl.text();
						}
						if(IDD.tagName() == "curdraws" ) {
							QDomElement pl = IDD.toElement();
							club.curdraws = pl.text();
						}
						if(IDD.tagName() == "curlosts" ) {
							QDomElement pl = IDD.toElement();
							club.curlosts = pl.text();
						}
						if(IDD.tagName() == "curlwins" ) {
							QDomElement pl = IDD.toElement();
							club.curlwins = pl.text();
						}
						if(IDD.tagName() == "curldraws" ) {
							QDomElement pl = IDD.toElement();
							club.curldraws = pl.text();
						}
						if(IDD.tagName() == "curllosts" ) {
							QDomElement pl = IDD.toElement();
							club.curllosts = pl.text();
						}
						if(IDD.tagName() == "totmaxatt" ) {
							QDomElement pl = IDD.toElement();
							club.totmaxatt = pl.text();
						}
						if(IDD.tagName() == "curmaxatt" ) {
							QDomElement pl = IDD.toElement();
							club.curmaxatt = pl.text();
						}
						if(IDD.tagName() == "totavgatt" ) {
							QDomElement pl = IDD.toElement();
							club.totavgatt = pl.text();
						}
						if(IDD.tagName() == "curavgatt" ) {
							QDomElement pl = IDD.toElement();
							club.curavgatt = pl.text();
						}
						if(IDD.tagName() == "form" ) {
							QDomElement pl = IDD.toElement();
							club.form = pl.text();
						}
						if(IDD.tagName() == "for_a" ) {
							QDomElement pl = IDD.toElement();
							club.for_a = pl.text();
						}
						if(IDD.tagName() == "tactic_a" ) {
							QDomElement pl = IDD.toElement();
							club.tactic_a = pl.text();
						}
						if(IDD.tagName() == "attstyle_a" ) {
							QDomElement pl = IDD.toElement();
							club.attstyle_a = pl.text();
						}
						if(IDD.tagName() == "agr_a" ) {
							QDomElement pl = IDD.toElement();
							club.agr_a = pl.text();
						}
						if(IDD.tagName() == "cap_a" ) {
							QDomElement pl = IDD.toElement();
							club.cap_a = pl.text();
						}
						ID = ID.nextSibling();
					}
				}
				if( e.tagName() == "Stadium" ) {
					QDomNode ID = e.firstChild();
					while( !ID.isNull() ) {
						QDomElement IDD = ID.toElement();
						if(IDD.tagName() == "stadiumID" ) {
							QDomElement pl = IDD.toElement();
							stadium.id = pl.text();
						}
						if(IDD.tagName() == "name" ) {
							QDomElement pl = IDD.toElement();
							stadium.name = pl.text();
						}
						if(IDD.tagName() == "field_status" ) {
							QDomElement pl = IDD.toElement();
							stadium.field_status = pl.text();
						}
						if(IDD.tagName() == "price_league" ) {
							QDomElement pl = IDD.toElement();
							stadium.priceLeague = pl.text();
						}
						if(IDD.tagName() == "price_cup" ) {
							QDomElement pl = IDD.toElement();
							stadium.priceCup = pl.text();
						}
						if(IDD.tagName() == "price_friendly" ) {
							QDomElement pl = IDD.toElement();
							stadium.priceFriendly = pl.text();
						}
						if(IDD.tagName() == "price_friendlycup" ) {
							QDomElement pl = IDD.toElement();
							stadium.priceFriendlyCup = pl.text();
						}
						if(IDD.tagName() == "fanpot" ) {
							QDomElement pl = IDD.toElement();
							stadium.fans = pl.text();
						}
						if(IDD.tagName() == "fansatis" ) {
							QDomElement pl = IDD.toElement();
							stadium.fanSatis = pl.text();
						}
						if(IDD.tagName() == "cap_n" ) {
							QDomElement pl = IDD.toElement();
							stadium.cap_n = pl.text();
						}
						if(IDD.tagName() == "cap_e" ) {
							QDomElement pl = IDD.toElement();
							stadium.cap_e = pl.text();
						}
						if(IDD.tagName() == "cap_w" ) {
							QDomElement pl = IDD.toElement();
							stadium.cap_w = pl.text();
						}
						if(IDD.tagName() == "cap_s" ) {
							QDomElement pl = IDD.toElement();
							stadium.cap_s = pl.text();
						}
						if(IDD.tagName() == "lights_ne" ) {
							QDomElement pl = IDD.toElement();
							stadium.lights_ne = pl.text();
						}
						if(IDD.tagName() == "lights_se" ) {
							QDomElement pl = IDD.toElement();
							stadium.lights_se = pl.text();
						}
						if(IDD.tagName() == "lights_nw" ) {
							QDomElement pl = IDD.toElement();
							stadium.lights_nw = pl.text();
						}
						if(IDD.tagName() == "lights_sw" ) {
							QDomElement pl = IDD.toElement();
							stadium.lights_sw = pl.text();
						}
						if(IDD.tagName() == "sb1" ) {
							QDomElement pl = IDD.toElement();
							stadium.sb1 = pl.text();
						}
						if(IDD.tagName() == "sb2" ) {
							QDomElement pl = IDD.toElement();
							stadium.sb2 = pl.text();
						}
						if(IDD.tagName() == "field" ) {
							QDomElement pl = IDD.toElement();
							stadium.field = pl.text();
						}
						if(IDD.tagName() == "parking" ) {
							QDomElement pl = IDD.toElement();
							stadium.parking = pl.text();
						}
						if(IDD.tagName() == "wc" ) {
							QDomElement pl = IDD.toElement();
							stadium.wc = pl.text();
						}
						if(IDD.tagName() == "kantine" ) {
							QDomElement pl = IDD.toElement();
							stadium.bar = pl.text();
						}
						if(IDD.tagName() == "youth_centre" ) {
							QDomElement pl = IDD.toElement();
							stadium.youth_center = pl.text();
						}
						if(IDD.tagName() == "ds_n" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_n = pl.text();
						}
						if(IDD.tagName() == "ds_e" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_e = pl.text();
						}
						if(IDD.tagName() == "ds_w" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_w = pl.text();
						}
						if(IDD.tagName() == "ds_sn" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_s = pl.text();
						}
						if(IDD.tagName() == "ds_lights_ne" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_lights_ne = pl.text();
						}
						if(IDD.tagName() == "ds_lights_se" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_lights_se = pl.text();
						}
						if(IDD.tagName() == "ds_lights_nw" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_lights_nw = pl.text();
						}
						if(IDD.tagName() == "ds_lights_sw" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_lights_sw = pl.text();
						}
						if(IDD.tagName() == "ds_sb1" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_sb1 = pl.text();
						}
						if(IDD.tagName() == "ds_sb2" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_sb2 = pl.text();
						}
						if(IDD.tagName() == "ds_bar" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_bar = pl.text();
						}
						if(IDD.tagName() == "ds_wc" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_wc = pl.text();
						}
						if(IDD.tagName() == "ds_park" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_park = pl.text();
						}
						if(IDD.tagName() == "ds_field" ) {
							QDomElement pl = IDD.toElement();
							stadium.ds_field = pl.text();
						}
						if(IDD.tagName() == "park_fu" ) {
							QDomElement pl = IDD.toElement();
							stadium.park_fu = pl.text().toInt();
						}
						if(IDD.tagName() == "wc_fu" ) {
							QDomElement pl = IDD.toElement();
							stadium.wc_fu = pl.text().toInt();
						}
						if(IDD.tagName() == "bar_fu" ) {
							QDomElement pl = IDD.toElement();
							stadium.bar_fu = pl.text().toInt();
						}
						if(IDD.tagName() == "sb_fu" ) {
							QDomElement pl = IDD.toElement();
							stadium.sb_fu = pl.text().toInt();
						}
						if(IDD.tagName() == "lights_fu" ) {
							QDomElement pl = IDD.toElement();
							stadium.lights_fu = pl.text().toInt();
						}
						ID = ID.nextSibling();
					}
				}
				if( e.tagName() == "StaffMembers" ) {
					QDomNode p = e.firstChild();
					int curStaff = 0;
					while( !p.isNull() ) {
						QDomElement pp = p.toElement();
						if( pp.tagName() == "Staff" ) {
							QDomNode ID = pp.firstChild();
							while( !ID.isNull() ) {
								QDomElement IDD = ID.toElement();
								if(IDD.tagName() == "staffID" ) {
									QDomElement pl = IDD.toElement();
									staff[curStaff].id = pl.text();
								}
								if(IDD.tagName() == "role" ) {
									QDomElement pl = IDD.toElement();
									staff[curStaff].role = pl.text();
								}
								if(IDD.tagName() == "name" ) {
									QDomElement pl = IDD.toElement();
									staff[curStaff].name = pl.text();
								}
								if(IDD.tagName() == "wage" ) {
									QDomElement pl = IDD.toElement();
									staff[curStaff].wage = pl.text();
								}
								if(IDD.tagName() == "contr" ) {
									QDomElement pl = IDD.toElement();
									staff[curStaff].contr = pl.text();
								}
								if(IDD.tagName() == "age" ) {
									QDomElement pl = IDD.toElement();
									staff[curStaff].age = pl.text();
								}
								if(IDD.tagName() == "bd" ) {
									QDomElement pl = IDD.toElement();
									staff[curStaff].birth = pl.text();
								}
								if(IDD.tagName() == "inservice" ) {
									QDomElement pl = IDD.toElement();
									staff[curStaff].inservice = pl.text();
								}
								if(IDD.tagName() == "course_slot" ) {
									QDomElement pl = IDD.toElement();
									staff[curStaff].course = pl.text();
								}
								if(IDD.tagName() == "rat" ) {
									QDomElement pl = IDD.toElement();
									staff[curStaff].rating = pl.text();
								}
								ID = ID.nextSibling();
							}
						}
						p = p.nextSibling();
						curStaff++;
						staffCnt++;
					}
				}
				if( e.tagName() == "Players" ) {
					QDomNode p = e.firstChild();
					int curPlayer = 0;
					while( !p.isNull() ) {
						QDomElement pp = p.toElement();
						if( pp.tagName() == "Player" ) {
							QDomNode ID = pp.firstChild();
							while( !ID.isNull() ) {
								QDomElement IDD = ID.toElement();
								if(IDD.tagName() == "id" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].id = pl.text();
								}
								if(IDD.tagName() == "fn" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].fname = pl.text();
								}
								if(IDD.tagName() == "ln" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].lname = pl.text();
								}
								if(IDD.tagName() == "pos" ) {
									QDomElement pl = IDD.toElement();
									switch(pl.text().toInt()) {
										case 0: pls[curPlayer].position = "GK"; break;
										case 1: pls[curPlayer].position = "LB"; break;
										case 2: pls[curPlayer].position = "CB"; break;
										case 3: pls[curPlayer].position = "SW"; break;
										case 4: pls[curPlayer].position = "RB"; break;
										case 5: pls[curPlayer].position = "LM"; break;
										case 6: pls[curPlayer].position = "CM"; break;
										case 7: pls[curPlayer].position = "RM"; break;
										case 8: pls[curPlayer].position = "LF"; break;
										case 9: pls[curPlayer].position = "CF"; break;
										case 10: pls[curPlayer].position = "RF"; break;
										case 11: pls[curPlayer].position = "SB1"; break;
										case 12: pls[curPlayer].position = "SB2"; break;
										case 13: pls[curPlayer].position = "SB3"; break;
										case 14: pls[curPlayer].position = "SB4"; break;
										case 15: pls[curPlayer].position = "SB5"; break;
										case 16: pls[curPlayer].position = "--"; break;
									}
								}
								if(IDD.tagName() == "rat" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].rating = pl.text();
								}
								if(IDD.tagName() == "mor" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].morale = pl.text();
								}
								if(IDD.tagName() == "agr" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].aggresion = pl.text();
								}
								if(IDD.tagName() == "fit" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].fitness = pl.text();
								}
								if(IDD.tagName() == "exp" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].experience = pl.text();
								}
								if(IDD.tagName() == "con" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].condition = pl.text();
								}
								if(IDD.tagName() == "sp" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].speed = pl.text();
								}
								if(IDD.tagName() == "bc" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].ballCntrl = pl.text();
								}
								if(IDD.tagName() == "sk1" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].skill[0] = pl.text();
								}
								if(IDD.tagName() == "sk2" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].skill[1] = pl.text();
								}
								if(IDD.tagName() == "sk3" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].skill[2] = pl.text();
								}
								if(IDD.tagName() == "sk4" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].skill[3] = pl.text();
								}
								if(IDD.tagName() == "ssk1" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].specSkill[0] = pl.text();
								}
								if(IDD.tagName() == "ssk2" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].specSkill[1] = pl.text();
								}
								if(IDD.tagName() == "nr" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].number = pl.text();
								}
								if(IDD.tagName() == "bd" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].birth = pl.text();
								}
								if(IDD.tagName() == "age" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].age = pl.text();
								}
								if(IDD.tagName() == "h" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].height = pl.text();
								}
								if(IDD.tagName() == "w" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].weight = pl.text();
								}
								if(IDD.tagName() == "f" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].foot = pl.text();
								}
								if(IDD.tagName() == "injured" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].injured = pl.text();
								}
								if(IDD.tagName() == "injury" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].injury = pl.text();
								}
								if(IDD.tagName() == "l_sus" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].leagueSusp = pl.text();
								}
								if(IDD.tagName() == "c_sus" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].cupSusp = pl.text();
								}
								if(IDD.tagName() == "contr" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].contract = pl.text();
								}
								if(IDD.tagName() == "wage" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].wage = pl.text();
								}
								if(IDD.tagName() == "house" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].house = pl.text();
								}
								if(IDD.tagName() == "car" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].car = pl.text();
								}
								if(IDD.tagName() == "s_bonus" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].signBonus = pl.text();
								}
								if(IDD.tagName() == "w_bonus" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].winBonus = pl.text();
								}
								if(IDD.tagName() == "t_games" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].totalGames = pl.text();
								}
								if(IDD.tagName() == "t_g_l" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].leagueGoals = pl.text();
								}
								if(IDD.tagName() == "t_g_c" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].cupGoals = pl.text();
								}
								if(IDD.tagName() == "t_y_l" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].leagueCardsY = pl.text();
								}
								if(IDD.tagName() == "t_y_c" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].cupCardsY = pl.text();
								}
								if(IDD.tagName() == "t_r_l" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].leagueCardsR = pl.text();
								}
								if(IDD.tagName() == "t_r_c" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].cupCardsR = pl.text();
								}
								if(IDD.tagName() == "t_g_f" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].friendlyGoals = pl.text();
								}
								if(IDD.tagName() == "t_y_f" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].friendlyCardsY = pl.text();
								}
								if(IDD.tagName() == "t_r_f" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].friendlyCardsR = pl.text();
								}
								if(IDD.tagName() == "t_bles" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].totalInjuries = pl.text();
								}
								if(IDD.tagName() == "c_games" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].curGames = pl.text();
								}
								if(IDD.tagName() == "c_g_l" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].curLeagueGoals = pl.text();
								}
								if(IDD.tagName() == "c_g_c" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].curCupGoals = pl.text();
								}
								if(IDD.tagName() == "c_y_l" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].curLeagueCardsY = pl.text();
								}
								if(IDD.tagName() == "c_y_c" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].curCupCardsY = pl.text();
								}
								if(IDD.tagName() == "c_r_l" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].curLeagueCardsR = pl.text();
								}
								if(IDD.tagName() == "c_r_c" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].curCupCardsR = pl.text();
								}
								if(IDD.tagName() == "c_g_f" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].curFriendlyGoals = pl.text();
								}
								if(IDD.tagName() == "c_y_f" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].curFriendlyCardsY = pl.text();
								}
								if(IDD.tagName() == "c_r_f" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].curFriendlyCardsR = pl.text();
								}
								if(IDD.tagName() == "c_inj" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].curInjuries = pl.text();
								}
								if(IDD.tagName() == "b_rat" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].bestRate = pl.text();
								}
								if(IDD.tagName() == "form" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].form = pl.text();
								}
								if(IDD.tagName() == "nick" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].nick = pl.text();
								}
								if(IDD.tagName() == "ctr" ) {
									QDomElement pl = IDD.toElement();
									pls[curPlayer].country = pl.text();
								}
								ID = ID.nextSibling();
							}
						}
						p = p.nextSibling();
						curPlayer++;
						playerCnt++;
					}
				}
			}
			n = n.nextSibling();
		}
	}
}

/**
 * \brief Function partially parsing input XML.
 *
 * Parse only information about current season.
 * Used to assigning season to input xml on the fly.
 * \param[in] data path to input xml.
 */
void quickparse(const QString &data) {
	QDomDocument doc("spdt");
	QFile file( data );
	file.open( QIODevice::ReadOnly );
	doc.setContent( &file );
	file.close();
		
	QDomElement root = doc.documentElement();
	if( root.tagName() == "SoccerProject" ) {
		QDomNode n = root.firstChild();
		
		while( !n.isNull() ) {
			QDomElement e = n.toElement();
			if( !e.isNull() ) {
				if( e.tagName() == "GlobalInfo" ) {
					QDomNode ID = e.firstChild();
					while( !ID.isNull() ) {
						QDomElement IDD = ID.toElement();
						if(IDD.tagName() == "cur_globalslot" ) {
							QDomElement pl = IDD.toElement();
							globSlot = pl.text().toInt();
						} else if(IDD.tagName() == "cur_slot" ) {
							QDomElement pl = IDD.toElement();
							curSlot = pl.text().toInt();
						} else if(IDD.tagName() == "cur_season" ) {
							QDomElement pl = IDD.toElement();
							curSeason = pl.text().toInt();
						}
						ID = ID.nextSibling();
					}
				}
			}
			n = n.nextSibling();
		}
	}
}

int main(int argc, char **argv) {
	QSettings settings("config/global.ini", QSettings::IniFormat);
	QString lang = settings.value("lang", "en").toString();
	
	QApplication app(argc, argv);
	QPixmap pixmap(453,300);
	QByteArray bArray;
	QFile PixmapFile("./img/splash.jpg");
	if(!PixmapFile.open(QIODevice::ReadOnly))
	{
		qDebug("Error loading Pixmap");
		return false;
	}

	bArray=PixmapFile.readAll().toBase64();

	if(!pixmap.loadFromData( bArray.fromBase64(bArray)))
	{
		qDebug()<<"Error pixmap processing";
		return 0;
	}

	QSplashScreen splash(pixmap);
	splash.show();
	splash.showMessage("[0.2.7]     please wait parsing data files..", Qt::AlignBottom | Qt::AlignCenter, Qt::white);
	QTranslator translator;
	translator.load("lang/tran_"+lang);
	app.installTranslator(&translator);
	MainWindow win;
	win.show();
	splash.finish(&win);
	return app.exec();
}

