/*******************************************************************
Jan Cermak | johniez | aspt.johniez.com
Creative Commons 2.5 Attribution-NonCommercial-NoDerivs 2.5 license
http://creativecommons.org/licenses/by-nc-nd/2.5/legalcode
*******************************************************************/

#include "mainwindow.h"

/**
 * \brief Main Window constructor.
 */
MainWindow::MainWindow(QWidget * parent) : QWidget(parent) {
	tabWidget = new QTabWidget;
	conf = new ConfigTab(this);
	player = new PlayerTab(this);
	perform = new PerformanceTab(this);
	staff = new StaffTab(this);
	stadium = new StadiumTab(this);
	club = new ClubTab(this);
	load = new LoadTab(this);
	about = new AboutTab(this);
	
	tabWidget->addTab(conf, tr("Config"));
	tabWidget->addTab(player, tr("Players"));
	tabWidget->addTab(perform, tr("Performance"));
	tabWidget->addTab(staff, tr("Staff"));
	tabWidget->addTab(stadium, tr("Stadium"));
	tabWidget->addTab(club, tr("Club"));
	tabWidget->addTab(load, tr("Load"));
	tabWidget->addTab(about, tr("About"));
	connect(conf, SIGNAL(dataLoaded()), player, SLOT(dataChanged()));
	connect(conf, SIGNAL(dataLoaded()), staff, SLOT(dataChanged()));
	connect(conf, SIGNAL(dataLoaded()), stadium, SLOT(dataChanged()));
	connect(conf, SIGNAL(dataLoaded()), club, SLOT(dataChanged()));
	connect(conf, SIGNAL(dataLoaded()), perform, SLOT(dataChanged()));
	
	connect(load, SIGNAL(loaded()), player, SLOT(dataChanged()));
	connect(load, SIGNAL(loaded()), staff, SLOT(dataChanged()));
	connect(load, SIGNAL(loaded()), stadium, SLOT(dataChanged()));
	connect(load, SIGNAL(loaded()), club, SLOT(dataChanged()));
	connect(load, SIGNAL(loaded()), perform, SLOT(dataChanged()));
	
	mainLayout = new QVBoxLayout;
	mainLayout->addWidget(tabWidget);
	setLayout(mainLayout);
}

/**
 * \brief Main Window destructor.
 */
MainWindow::~MainWindow() {
	delete conf;
	delete player;
	delete perform;
	delete staff;
	delete stadium;
	delete club;
	delete load;
	delete about;
	delete tabWidget;
	delete mainLayout;
}
