/*******************************************************************
Jan Cermak | johniez | aspt.johniez.com
Creative Commons 2.5 Attribution-NonCommercial-NoDerivs 2.5 license
http://creativecommons.org/licenses/by-nc-nd/2.5/legalcode
*******************************************************************/

#include "performance.h"

/**
 * \brief Init UI.
 */
void PerformanceTab::init() {
	QSettings settings("config/formation.ini", QSettings::IniFormat);
	
	format = new QComboBox();
	format->addItem("---", QVariant(0));
	format->addItem("5-4-1", QVariant(1));
	format->addItem("5-3-2", QVariant(2));
	format->addItem("4-3-3", QVariant(3));
	format->addItem("4-4-2", QVariant(4));
	format->addItem("4-5-1", QVariant(5));
	format->addItem("3-4-3", QVariant(6));
	format->addItem("3-5-2", QVariant(7));
	format->setToolTip(tr("Team formation."));
	
	reorderPl = new QPushButton(tr("reorder players"));
	reorderPl->setToolTip(tr("This button set on positions with wrong player type this player, who plays there (LM on LM post..)."));
	
	aggression = new QComboBox();
	for(int i=0; i<=100; i+=5) {
		aggression->addItem(tr("aggression ") + QString().setNum(i) + "%", i);
	}
	aggression->setCurrentIndex(settings.value("aggr", 0).toInt()/5);
	aggression->setToolTip(tr("Team aggression, same as you set in match."));
	aggress = settings.value("aggr", 0).toInt();
	
	home = new QComboBox();
	home->addItem(tr("play home"), 0.0);
	home->addItem(tr("play away"), 0.1);
	home->setToolTip(tr("Where you will play the match."));
	
	for(int j=0; j<11; ++j) {
		plCont[j] = new QHBoxLayout();
		player[j] = new QComboBox();
		orders[j] = new QComboBox();
		orders[j]->setToolTip(tr("'Ind. order' mean one of: Normal, Play along, Play along wing, Play it out, Passing, Own chance, Targetman and Free role."));
		orders[j]->addItem(tr("ind. order"), 0);
		for(int i=0; i<playerCnt; ++i) {
			int oldPenale = 0;
			int age = pls[i].age.toInt();
			double perf = ((pls[i].morale.toDouble()+pls[i].fitness.toDouble())/200)*pls[i].bestRate.toDouble();
			if(age > 30) {
				oldPenale = (age-30)*3;		// 3 points penale per each year over 30
				perf -= oldPenale;
			}
			player[j]->addItem("[" + pls[i].position + "] " + pls[i].fname + " " + pls[i].lname, QVariant(perf));
		}
		player[j]->setCurrentIndex(settings.value("Player/"+QString().setNum(j), 0).toInt());
		postLabel[j] = new QLabel("pos");
		plPerfLabel[j] = new QLabel(QString().setNum(player[j]->itemData(player[j]->currentIndex()).toDouble(), 'f', 2));
		plCont[j]->addWidget(postLabel[j]);
		plCont[j]->addWidget(player[j]);
		plCont[j]->addWidget(orders[j]);
		plCont[j]->addWidget(plPerfLabel[j]);
	}
	
	container = new QHBoxLayout();
	
	container->addWidget(format);
	container->addWidget(reorderPl);
	container->addWidget(aggression);
	container->addWidget(home);
	mainLayout->addLayout(container);
	for(int j=0; j<11; ++j) mainLayout->addLayout(plCont[j]);
	
	cButt = new QPushButton(tr("count team performance"));
	mainLayout->addWidget(cButt);
	
	result = new QLabel(tr("Set formation, aggression and players.<br>") + "<span style=\"color:red\">" + tr("Results could be inaccurate!") + "</span><br>" + tr("This version do not penalize players at wrong position!<br>See http://flyspray.johniez.com/task/14"));
	mainLayout->addWidget(result);
	
	format->setCurrentIndex(settings.value("form", 0).toInt());
	formatChange(settings.value("form", 0).toInt());
	
	connect(format, SIGNAL(currentIndexChanged(int)), this, SLOT(formatChange(int)));
	connect(aggression, SIGNAL(currentIndexChanged(int)), this, SLOT(aggressChange(int)));
	connect(cButt, SIGNAL(clicked()), this, SLOT(recount()));
	for(int i=0; i<11; i++) {
		connect(player[i], SIGNAL(currentIndexChanged(int)), this, SLOT(playerChange(int)));
	}
	connect(reorderPl, SIGNAL(clicked()), this, SLOT(reorderPlayers()));
	mainLayout->update();
}

/**
 * \brief Performance Tab constructor.
 */
PerformanceTab::PerformanceTab(QWidget *parent): QWidget(parent), defs(0), mids(0), fors(0) {
	mainLayout = new QVBoxLayout;
	setLayout(mainLayout);
	init();
}

/**
 * \brief Performance Tab destructor.
 */
PerformanceTab::~PerformanceTab() {
	for(int i=0; i<11; ++i) {
		delete player[i];
		delete postLabel[i];
		delete plPerfLabel[i];
		delete orders[i];
		delete plCont[i];
	}
	delete format;
	delete aggression;
	delete home;
	delete result;
	delete cButt;
	delete container;
	delete reorderPl;
	delete mainLayout;
}

/**
 * \brief Slot assigned to data change action.
 */
void PerformanceTab::dataChanged() {
	container->removeWidget(format);
	delete format;
	container->removeWidget(aggression);
	delete aggression;
	container->removeWidget(home);
	delete home;
	container->removeWidget(reorderPl);
	delete reorderPl;
	mainLayout->removeWidget(reinterpret_cast<QWidget*>(container));
	delete container;
	
	for(int i=0; i<11; ++i) {
		mainLayout->removeWidget(reinterpret_cast<QWidget*>(plCont[i]));
		delete plCont[i];
		delete player[i];
		delete plPerfLabel[i];
		delete postLabel[i];
		delete orders[i];
	}
	mainLayout->removeWidget(cButt);
	delete cButt;
	mainLayout->removeWidget(result);
	delete result;
	mainLayout->update();
	init();
}

/**
 * \brief Set adequate player post by selected formation.
 */
void PerformanceTab::postLabels() {
	int LMpos = 0;
	if(!defsC) {
		for(int i=0; i<11; ++i) {
			postLabel[i]->setText("??");
		}
	}
	postLabel[0]->setText("GK");
	postLabel[1]->setText("LB");
	orders[1]->clear();
	orders[1]->addItem(tr("ind. order"), 0);
	orders[1]->addItem(tr("offensive"), 2);
	postLabel[2]->setText("CB");
	switch(defsC) {
		case 5:
			postLabel[3]->setText("SW");
			orders[3]->clear();
			orders[3]->addItem(tr("ind. order"), 0);
			postLabel[4]->setText("CB");
			orders[4]->clear();
			orders[4]->addItem(tr("ind. order"), 0);
			postLabel[5]->setText("RB");
			orders[5]->clear();
			orders[5]->addItem(tr("ind. order"), 0);
			orders[5]->addItem(tr("offensive"), 2);
			LMpos = 6;
			break;
		case 4:
			postLabel[3]->setText("CB");
			orders[3]->clear();
			orders[3]->addItem(tr("ind. order"), 0);
			postLabel[4]->setText("RB");
			orders[4]->clear();
			orders[4]->addItem(tr("ind. order"), 0);
			orders[4]->addItem(tr("offensive"), 2);
			LMpos = 5;
			break;
		case 3:
			postLabel[3]->setText("RB");
			orders[3]->clear();
			orders[3]->addItem(tr("ind. order"), 0);
			orders[3]->addItem(tr("offensive"), 2);
			LMpos = 4;
			break;
	}
	switch(midsC) {
		case 5:
			postLabel[LMpos]->setText("LM");
			postLabel[LMpos+1]->setText("CM");
			postLabel[LMpos+2]->setText("CM");
			postLabel[LMpos+3]->setText("CM");
			postLabel[LMpos+4]->setText("RM");
			break;
		case 4:
			postLabel[LMpos]->setText("LM");
			postLabel[LMpos+1]->setText("CM");
			postLabel[LMpos+2]->setText("CM");
			postLabel[LMpos+3]->setText("RM");
			break;
		case 3:
			postLabel[LMpos]->setText("LM");
			postLabel[LMpos+1]->setText("CM");
			postLabel[LMpos+2]->setText("RM");
	}
	for(int i=LMpos; i<LMpos+midsC; ++i) {
		orders[i]->clear();
		orders[i]->addItem(tr("ind. order"), 0);
		orders[i]->addItem(tr("defensive"), 1);
		orders[i]->addItem(tr("offensive"), 2);
	}
	switch(forsC) {
		case 3:
			postLabel[8]->setText("LF");
			orders[8]->clear();
			orders[8]->addItem(tr("ind. order"), 0);
			orders[8]->addItem(tr("defensive"), 1);
			postLabel[9]->setText("CF");
			orders[9]->clear();
			orders[9]->addItem(tr("ind. order"), 0);
			postLabel[10]->setText("RF");
			orders[10]->clear();
			orders[10]->addItem(tr("ind. order"), 0);
			orders[10]->addItem(tr("defensive"), 1);
			break;
		case 2:
			postLabel[9]->setText("CF");
			orders[9]->clear();
			orders[9]->addItem(tr("ind. order"), 0);
			postLabel[10]->setText("CF");
			orders[10]->clear();
			orders[10]->addItem(tr("ind. order"), 0);
			break;
		case 1:
			postLabel[10]->setText("CF");
			orders[10]->clear();
			orders[10]->addItem(tr("ind. order"), 0);
			break;
	}
}

/**
 * \brief Count performance of each line (def, mid, fwd).
 *
 * Count with offensive/defensive order of each player.
 */
void PerformanceTab::countPerf() {
	defs = 0;
	mids = 0;
	fors = 0;
	double perf;
	for(int i=0; i<=defsC; ++i) {
		perf = player[i]->itemData(player[i]->currentIndex()).toDouble();
		if(orders[i]->itemData(orders[i]->currentIndex()).toInt()==0) {
			defs += perf;
		} else {
			defs += (0.78 * perf);
			mids += (0.22 * perf);
		}
	}
	for(int i=defsC+1; i<=defsC+midsC; ++i) {
		perf = player[i]->itemData(player[i]->currentIndex()).toDouble();
		if(orders[i]->itemData(orders[i]->currentIndex()).toInt()==0) {
			mids += perf;
		} else if(orders[i]->itemData(orders[i]->currentIndex()).toInt()==1) {
			defs += (0.22 * perf);
			mids += (0.78 * perf);
		} else {
			fors += (0.22 * perf);
			mids += (0.78 * perf);
		}
	}
	for(int i=defsC+midsC+1; i<11; ++i) {
		perf = player[i]->itemData(player[i]->currentIndex()).toDouble();
		if(orders[i]->itemData(orders[i]->currentIndex()).toInt()==0) {
			fors += perf;
		} else {
			fors += (0.78 * perf);
			mids += (0.22 * perf);
		}
	}
}

/**
 * \brief Slot assigned to "count performance" button.
 *
 * Print all play-variants points..
 */
void PerformanceTab::recount() {
	double homeMod = home->itemData(home->currentIndex()).toDouble();
	double pre = (1.0+((double)aggress/1000))/(7.0 - (club.spirit.toDouble()/1000) + homeMod);

	countPerf();
	QString text;
	if(!defsC) text = tr("Choose a formation");
	else {
		double O = pre*defs;
		double M = pre*mids;
		double F = pre*fors;
		text = "<table cellpadding=\"1\" width=\"100%\"><tr><td>----</td><td style=\"color:blue;\"  align=\"right\">"+tr("Long Ball")+"</td><td align=\"right\">"+tr("Without tactics")+"</td><td style=\"color:blue;\" align=\"right\">"+tr("Kick and rush")+"</td><td align=\"right\">"+tr("Passing")+"</td><td style=\"color:blue;\" align=\"right\">"+tr("Defensive wall")+"</td></tr><tr><td>D</td><td style=\"color:blue;\" align=\"right\">"+QString().setNum(O*1.05,'f',2)+"</td><td align=\"right\">"+QString().setNum(O,'f',2)+"</td><td style=\"color:blue;\" align=\"right\">"+QString().setNum(O*0.9,'f',2)+"</td><td align=\"right\">"+QString().setNum(O*0.9,'f',2)+"</td><td style=\"color:blue;\" align=\"right\">"+QString().setNum(O*1.08,'f',2)+"</td></tr><tr><td>M</td><td style=\"color:blue;\" align=\"right\">"+QString().setNum(M*0.9,'f',2)+"</td><td align=\"right\">"+QString().setNum(M,'f',2)+"</td><td style=\"color:blue;\" align=\"right\">"+QString().setNum(M*0.9,'f',2)+"</td><td align=\"right\">"+QString().setNum(M*1.1,'f',2)+"</td><td style=\"color:blue;\" align=\"right\">"+QString().setNum(M*0.9,'f',2)+"</td></tr><tr><td>F</td><td style=\"color:blue;\" align=\"right\">"+QString().setNum(F*1.05,'f',2)+"</td><td align=\"right\">"+QString().setNum(F,'f',2)+"</td><td style=\"color:blue;\" align=\"right\">"+QString().setNum(F*1.27,'f',2)+"</td><td align=\"right\">"+QString().setNum(F*0.9,'f',2)+"</td><td style=\"color:blue;\" align=\"right\">"+QString().setNum(F*0.9,'f',2)+"</td></tr><tr><td>Sum</td><td style=\"color:blue;\" align=\"right\">"+QString().setNum((O*1.05+M*0.9+F*1.05),'f',2)+"</td><td align=\"right\">"+QString().setNum((O+M+F),'f',2)+"</td><td style=\"color:blue;\" align=\"right\">"+QString().setNum((O*0.9+M*0.9+F*1.27),'f',2)+"</td><td align=\"right\">"+QString().setNum((O*0.9+M*1.1+F*0.9),'f',2)+"</td><td style=\"color:blue;\" align=\"right\">"+QString().setNum((O*1.08+M*0.9+F*0.9),'f',2)+"</td></tr></table>";
	}
	result->setText(text);
}

/**
 * \brief Slot assigned to aggression change.
 *
 * \param[in] a Aggression ID.
 * Save aggression to config file.
 */
void PerformanceTab::aggressChange(int a) {
	aggress = a*5;
	QSettings settings("config/formation.ini", QSettings::IniFormat);
	settings.setValue("aggr", aggress);
	settings.sync();
}

/**
 * \brief Slot assigned to formation change.
 * \param[in] t Formation ID.
 */
void PerformanceTab::formatChange(int t) {
	QSettings settings("config/formation.ini", QSettings::IniFormat);
	if(t<8 && t>=0) { settings.setValue("form", t); settings.sync(); }
	switch(t) {
		case 0: 
			defsC = 0; midsC = 0; forsC = 0;
			break;
		case 1:
			defsC = 5; midsC = 4; forsC = 1;
			break;
		case 2:
			defsC = 5; midsC = 3; forsC = 2;
			break;
		case 3:
			defsC = 4; midsC = 3; forsC = 3;
			break;
		case 4:
			defsC = 4; midsC = 4; forsC = 2;
			break;
		case 5:
			defsC = 4; midsC = 5; forsC = 1;
			break;
		case 6:
			defsC = 3; midsC = 4; forsC = 3;
			break;
		case 7:
			defsC = 3; midsC = 5; forsC = 2;
			break;
	}
	postLabels();
	reorderPlayers();
}

/**
 * \brief Slot assigned to player combobox changes.
 * \param[in] id possition ID
 */
void PerformanceTab::playerChange(int id) {
	id = 1;	//avoid warning :-D
	QSettings settings("config/formation.ini", QSettings::IniFormat);
	for(int i=0; i<11; ++i) {
		settings.setValue("Player/"+QString().setNum(i), player[i]->currentIndex());
		plPerfLabel[i]->setText(QString().setNum(player[i]->itemData(player[i]->currentIndex()).toDouble(), 'f', 2)); //player[i]->itemData(player[i]->currentIndex()).toInt()
	}
	settings.sync();
}

/**
 * \brief Slot assigned to "re-order players" button.
 *
 * If there are players assigned to wrong possition (by selected formation),
 * then this function give here players with correct post.
 * This do not look at player performance, first is selected..
 */
void PerformanceTab::reorderPlayers() {
	int i;
	int from = 0;
	for(i=1; i<=defsC; ++i) {		// defenders
		if(i==1) {		// LB
			if(pls[player[i]->currentIndex()].position != "LB") {
				player[i]->setCurrentIndex(findFirstOnPost("LB"));
			}
		} else if(i==defsC) {		// RB
			if(pls[player[i]->currentIndex()].position != "RB") {
				player[i]->setCurrentIndex(findFirstOnPost("RB"));
			}
			// RB is last managed from defenders, should set finding from him
			from = player[i]->currentIndex();
		} else if(defsC == 5 && i==3) {		// SW
			if(pls[player[i]->currentIndex()].position != "SW") {
				player[i]->setCurrentIndex(findFirstOnPost("SW"));
			}
		} else {		// CB
			if(pls[player[i]->currentIndex()].position != "CB") {
				player[i]->setCurrentIndex(findFirstOnPost("CB"));
			}
		}
	}
	for(i=defsC+1; i<=defsC+midsC; ++i) {
		if(i==defsC+1) {		// LM
			if(pls[player[i]->currentIndex()].position != "LM") {
				player[i]->setCurrentIndex(findFirstOnPost("LM"));
			}
		} else if(i==defsC+midsC) {		// RM
			if(pls[player[i]->currentIndex()].position != "RM") {
				player[i]->setCurrentIndex(findFirstOnPost("RM"));
			}
			// RM is last managed from midfields, should set finding from him
			from = player[i]->currentIndex();
		} else {		// CM
			if(pls[player[i]->currentIndex()].position != "CM") {
				player[i]->setCurrentIndex(findFirstOnPost("CM"));
			}
		}
	}
	for(i=defsC+midsC+1; i<=defsC+midsC+forsC; ++i) {
		if(forsC==3) {
			if(i==defsC+midsC+1) {		// LF
				if(pls[player[i]->currentIndex()].position != "LF") {
					player[i]->setCurrentIndex(findFirstOnPost("LF"));
				}
			} else if(i==10) {		// RF
				if(pls[player[i]->currentIndex()].position != "RF") {
					player[i]->setCurrentIndex(findFirstOnPost("RF"));
				}
			}
		} else {		// always CF
			if(pls[player[i]->currentIndex()].position != "CF") {
				player[i]->setCurrentIndex(findFirstOnPost("CF"));
			}
		}
	}
}

/**
 * \brief Searching for first player with this post.
 * \param[in] post player possition.
 */
int PerformanceTab::findFirstOnPost(const QString &post) {
	for(int i=0; i<playerCnt; ++i) {
		if(post == pls[i].position) return i;
	}
	return 0;
}
