/*******************************************************************
Jan Cermak | johniez | aspt.johniez.com
Creative Commons 2.5 Attribution-NonCommercial-NoDerivs 2.5 license
http://creativecommons.org/licenses/by-nc-nd/2.5/legalcode
*******************************************************************/

#include "proxyset.h"

/**
 * \brief Proxy settings widget constructor.
 */
ProxySet::ProxySet(QWidget *parent) : QWidget(parent) {
	QSettings settings("config/global.ini", QSettings::IniFormat);
	useProxy = settings.value("Network/proxyUsed", 0).toInt();
	QString addrS = settings.value("Network/proxyAddr", "").toString();
	QString portS = settings.value("Network/proxyPort", "").toString();
	QString nameS = settings.value("Network/proxyName", "").toString();
	QString passS = settings.value("Network/proxyPass", "").toString();
	
	mainLayout = new QVBoxLayout;
	proxy = new QCheckBox(tr("Use proxy server"));
	proxy->setCheckState((Qt::CheckState) useProxy);
	connect(proxy, SIGNAL(stateChanged(int)), this, SLOT(checkChange(int)));
	addr = new QLabel(tr("proxy address:"));
	port = new QLabel(tr("proxy port:"));
	name = new QLabel(tr("proxy username:"));
	pass = new QLabel(tr("proxy password:"));
	addrP = new QLineEdit(addrS);
	portP = new QLineEdit(portS);
	nameP = new QLineEdit(nameS);
	passP = new QLineEdit(passS);
	passP->setEchoMode(QLineEdit::Password);
	saveButt = new QPushButton(tr("Save changes"));
	connect(saveButt, SIGNAL(clicked()), this, SLOT(save()));
	mainLayout->addWidget(proxy);
	mainLayout->addWidget(addr);
	mainLayout->addWidget(addrP);
	mainLayout->addWidget(port);
	mainLayout->addWidget(portP);
	mainLayout->addWidget(name);
	mainLayout->addWidget(nameP);
	mainLayout->addWidget(pass);
	mainLayout->addWidget(passP);
	mainLayout->addWidget(saveButt);
	setLayout(mainLayout);
	this->show();
}

/**
 * \brief Proxy settings destructor.
 */
ProxySet::~ProxySet() {
	delete addrP;
	delete portP;
	delete nameP;
	delete passP;
	delete proxy;
	delete addr;
	delete port;
	delete name;
	delete pass;
	delete saveButt;
	delete mainLayout;
}

/**
 * \brief Slot assigned to save button click.
 */
void ProxySet::save() {
	QSettings settings("config/global.ini", QSettings::IniFormat);
	settings.setValue("Network/proxyUsed", useProxy);
	settings.setValue("Network/proxyAddr", addrP->text());
	settings.setValue("Network/proxyPort", portP->text());
	settings.setValue("Network/proxyName", nameP->text());
	settings.setValue("Network/proxyPass", passP->text());
	settings.sync();
}

/**
 * \brief Slot assigned to check box changes.
 */
void ProxySet::checkChange(int state) {
	useProxy = state;
}
