/*******************************************************************
Jan Cermak | johniez | aspt.johniez.com
Creative Commons 2.5 Attribution-NonCommercial-NoDerivs 2.5 license
http://creativecommons.org/licenses/by-nc-nd/2.5/legalcode
*******************************************************************/

#include "stadiumtab.h"

/**
 * \brief Stadium Tab constructor.
 */
StadiumTab::StadiumTab(QWidget *parent) : QWidget(parent) {
	mainLayout = new QVBoxLayout;
	setLayout(mainLayout);
	init();
}

/**
 * \brief Stadium Tab destructor.
 */
StadiumTab::~StadiumTab() {
	delete label;
	delete mainLayout;
}

/**
 * \brief Print info about stadium from parsed data.
 */
void StadiumTab::init() {
	int cap = stadium.cap_n.toInt() + stadium.cap_e.toInt() + stadium.cap_w.toInt() + stadium.cap_s.toInt();
	QString text;
	text = "<table cellspacing=\"3\">";
	text += "<tr><td>" + tr("Stadium") + "</td><td><span style=\"color:red;\">" + stadium.name + "</span></td></tr>";
	text += "<tr><td>" + tr("Field condition") + "</td><td>" + stadium.field_status + "%</td></tr>";
	text += "<tr><td></td><td></td></tr>";
	text += "<tr><td>" + tr("Fan base") + "</td><td>" + stadium.fans + "</td></tr>";
	text += "<tr><td>" + tr("satisfaction") + "</td><td>" + stadium.fanSatis + "%</td></tr>";
	text += "<tr><td>" + tr("Capacity") + "</td><td><span style=\"color:red;\">" + QString().setNum(cap) + "</span></td></tr>";
	text += "<tr><td></td><td></td></tr>";
	text += "<tr><td>" + tr("Parking") + "</td><td>" + stadium.parking + "</td><td>(" + tr("minimal") + " " + QString().setNum((int)((float)cap/3)) + ")";
	if(stadium.park_fu) text += " <span style=\"color:red;\">" + tr("unhappy!!") + "</span>";
	text += "</td></tr>";
	text += "<tr><td>" + tr("Toilets") + "</td><td>" + stadium.wc + "</td><td>(" + tr("minimal") + " " + QString().setNum(cap*0.01) + ")";
	if(stadium.wc_fu) text += " <span style=\"color:red;\">" + tr("unhappy!!") + "</span>";
	text += "</td></tr>";
	text += "<tr><td>" + tr("Buffets") + "</td><td>" + stadium.bar + "</td><td>(" + tr("minimal") + " " + QString().setNum((int)(cap*0.0044)) + ")";
	if(stadium.bar_fu) text += " <span style=\"color:red;\">" + tr("unhappy!!") + "</span>";
	text += "</td></tr></table><hr>";
	text += "<table cellspacing=\"3\">";
	text += "<tr><td>" + tr("Price league") + "</td><td>" + stadium.priceLeague + "&euro; (" + QString().setNum(cap) + " " + tr("attendance gives cca. ") + QString().setNum(stadium.priceLeague.toInt()*(0.9*cap)) + "&euro;)</td></tr>";
	text += "<tr><td>" + tr("Price cup") + "</td><td>" + stadium.priceCup + "&euro; (" + QString().setNum(cap) + " " + tr("attendance gives cca. ") + QString().setNum(stadium.priceCup.toInt()*(0.9*cap)) + "&euro;)</td></tr>";
	text += "<tr><td>" + tr("Price friendly") + "</td><td>" + stadium.priceFriendly + "&euro; (" + QString().setNum(cap/10) + " " + tr("attendance gives cca. ") + QString().setNum(stadium.priceFriendly.toInt()*(0.09*cap)) + "&euro;)</td></tr>";
	text += "<tr><td>" + tr("Price friendly cup") + "</td><td>" + stadium.priceFriendlyCup + "&euro; (" + QString().setNum(cap/10) + " " + tr("attendance gives cca. ") + QString().setNum(stadium.priceFriendlyCup.toInt()*(0.09*cap)) + "&euro;)</td></tr>";
	text += "</table><hr>";
	text += tr("Increasing 1000 places on stadium (calculations)") + ":<br>";
	if(stadium.parking.toInt() < ((cap+1000)/3)) {
		text += tr("You need") + "  " + QString().setNum((int)((float)(cap+1000)/3)) + "  " + tr("Parking places") + "<br>";
	}
	if(stadium.wc.toInt() < ((cap+1000)*0.01)) {
		text += tr("You need") + "  " + QString().setNum((cap+1000)*0.01) + "  " + tr("Toilets") + "<br>";
	}
	// but 60 for 21000 is still ok
	if(stadium.bar.toInt() < ((cap+1000)*0.0044)) {
		text += tr("You need") + "  " + QString().setNum((cap+1000)*0.0044) + "  " + tr("Buffets") + "<br>";
	}
	label = new QLabel(text);
	mainLayout->addWidget(label);
	mainLayout->update();
}

/**
 * \brief Slot assigned to data change action.
 */
void StadiumTab::dataChanged() {
	rebuildUI();
}

/**
 * \brief Destroy current UI and draw it again.
 */
void StadiumTab::rebuildUI() {
	mainLayout->removeWidget(label);
	delete label;
	mainLayout->update();
	init();
}
